#include "orbsvcs/Notify/Notify_Default_CO_Factory.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

int
TAO_Notify_Default_CO_Factory::init_svc ()
{
  // NOP.
  return 0;
}

TAO_END_VERSIONED_NAMESPACE_DECL
